<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" encoding="utf-8" indent="yes"/>
<xsl:template match="/guide">
<xsl:text disable-output-escaping="yes"><![CDATA[
<!DOCTYPE html 
  PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
]]>
</xsl:text>
<html lang="ja" xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><xsl:value-of select="title"/></title>
<meta http-equiv="Content-Type" content="text/html; charset=ISO-2022-JP"/>
<link rel="stylesheet" type="text/css" href="/~nakatuka/webpage.css"/>
<link rev="MADE" href="mailto:nakatuka@itc.aist-nara.ac.jp"/>
</head>
<body>
<hr/>
<xsl:apply-templates select="title"/>
<xsl:apply-templates select="author"/>
<hr/>
<div class="flushleft">
<small>
<b>Abstract:</b><br/>
<xsl:value-of select="abstract"/>
</small>
</div>
<xsl:apply-templates select="chapter"/>
<hr/>
</body>
</html>
</xsl:template>
<xsl:template match="/guide/title">
<h1><xsl:call-template name="styleclass"/></h1>
</xsl:template>
<xsl:template match="author">
<div class="author"><xsl:apply-templates select="mail|text()"/></div>
</xsl:template>
<xsl:template match="chapter">
<hr/>
<xsl:apply-templates select="title">
  <xsl:with-param name="chapnum" select="position()"/>
  <xsl:with-param name="chapid" select="@id"/>
</xsl:apply-templates>
<xsl:apply-templates select="section">
  <xsl:with-param name="chapnum" select="position()"/>
</xsl:apply-templates>
</xsl:template>
<xsl:template match="chapter/title">
<xsl:param name="chapnum"/>
<xsl:param name="chapid"/>
<xsl:variable name="titleid">
  <xsl:choose>
    <xsl:when test="$chapid"><xsl:value-of select="$chapid"/></xsl:when>
    <xsl:otherwise>chap<xsl:value-of select="$chapnum"/></xsl:otherwise>
  </xsl:choose>
</xsl:variable>
<h2 class="chapter"><a id="{$titleid}" name="{$titleid}"><xsl:value-of select="$chapnum"/>. <xsl:call-template name="styleclass"/></a></h2>
</xsl:template>
<xsl:template match="section">
<xsl:param name="chapnum"/>
<xsl:apply-templates select="title">
  <xsl:with-param name="secnum">
    <xsl:value-of select="$chapnum"/>.<xsl:number count="section[title]"/>
  </xsl:with-param>
  <xsl:with-param name="secid" select="@id"/>
</xsl:apply-templates>
<xsl:apply-templates select="body"/>
</xsl:template>
<xsl:template match="section/title">
<xsl:param name="secnum"/>
<xsl:param name="secid"/>
<xsl:variable name="titleid">
  <xsl:choose>
    <xsl:when test="$secid"><xsl:value-of select="$secid"/></xsl:when>
    <xsl:otherwise>sec<xsl:value-of select="$secnum"/></xsl:otherwise>
  </xsl:choose>
</xsl:variable>
<br/>
  <h3 class="section"><a id="{$titleid}" name="{$titleid}"><xsl:value-of select="$secnum"/>. <xsl:call-template name="styleclass"/></a></h3>
</xsl:template>
<xsl:template match="body">
<xsl:call-template name="allclass-without-text"/>
</xsl:template>
<xsl:template match="br">
<br><xsl:apply-templates select="text()"/></br>
</xsl:template>
<xsl:template match="note">
<p class="note"><b>Note:</b><br/><xsl:call-template name="allclass"/>
</p>
</xsl:template>
<xsl:template match="impo">
<p class="impo"><b>Impotant:</b><br/><xsl:call-template name="allclass"/>
</p>
</xsl:template>
<xsl:template match="warn">
<p class="warn"><b>Warning:</b><br/><xsl:call-template name="allclass"/>
</p>
</xsl:template>
<xsl:template match="pre">
<pre class="code"><xsl:call-template name="allclass"/>
</pre>
</xsl:template>
<xsl:template match="p">
<p><xsl:call-template name="allclass"/>
</p>
</xsl:template>
<xsl:template match="ul">
<ul>
<xsl:apply-templates select="li"/>
</ul>
</xsl:template>
<xsl:template match="ol">
<ol>
<xsl:apply-templates select="li"/>
</ol>
</xsl:template>
<xsl:template match="li">
<li><xsl:call-template name="allclass"/>
</li>
</xsl:template>
<xsl:template match="table">
<table>
<xsl:apply-templates select="tr"/>
</table>
</xsl:template>
<xsl:template match="tr">
<tr><xsl:apply-templates select="th|ti"/></tr>
</xsl:template>
<xsl:template match="th">
<th><xsl:call-template name="allclass"/></th>
</xsl:template>
<xsl:template match="ti">
<th><xsl:call-template name="allclass"/></th>
</xsl:template>
<xsl:template match="b|e">
<b><xsl:call-template name="stylelinkclass"/></b>
</xsl:template>
<xsl:template match="i|c">
<tt class="input"><xsl:call-template name="stylelinkclass"/></tt>
</xsl:template>
<xsl:template match="path">
<tt><xsl:call-template name="stylelinkclass"/></tt>
</xsl:template>
<xsl:template match="codenote"><tt class="codenote">// <xsl:call-template name="stylelinkclass"/></tt>
</xsl:template>
<xsl:template match="mail">
<a href="mailto:{@link}"><xsl:call-template name="styleclass"/></a>
</xsl:template>
<xsl:template match="uri">
<xsl:choose>
  <xsl:when test="@link">
    <a href="{@link}"><xsl:call-template name="styleclass"/></a>
  </xsl:when>
  <xsl:otherwise>
    <xsl:variable name="loc" select="."/>
    <a href="{$loc}"><xsl:call-template name="styleclass"/></a>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="allclass-without-text">
<xsl:apply-templates select="b|box|brite|c|codenote|comment|e|i|path|uri|mail|figure|fig|img|br|note|impo|warn|pre|p|table|ul|ol"/>
</xsl:template>
<xsl:template name="allclass">
<xsl:apply-templates select="b|box|brite|c|codenote|comment|e|i|path|uri|mail|figure|fig|img|br|note|impo|warn|pre|p|table|ul|ol|text()"/>
</xsl:template>
<xsl:template name="styleclass">
<xsl:apply-templates select="b|box|brite|c|codenote|comment|e|i|path|text()"/>
</xsl:template>
<xsl:template name="stylelinkclass">
<xsl:apply-templates select="b|box|brite|c|codenote|comment|e|i|path|uri|mail|text()"/>
</xsl:template>
</xsl:stylesheet>
